@@ -19,23 +19,6 @@ package org.apache.maven.plugins.shade;
  * under the License.
  */
 
-import com.google.common.base.Joiner;
-import com.google.common.collect.HashMultimap;
-import com.google.common.collect.Multimap;
-import org.apache.maven.plugin.MojoExecutionException;
-import org.apache.maven.plugins.shade.filter.Filter;
-import org.apache.maven.plugins.shade.relocation.Relocator;
-import org.apache.maven.plugins.shade.resource.ManifestResourceTransformer;
-import org.apache.maven.plugins.shade.resource.ResourceTransformer;
-import org.codehaus.plexus.component.annotations.Component;
-import org.codehaus.plexus.logging.AbstractLogEnabled;
-import org.codehaus.plexus.util.IOUtil;
-import org.objectweb.asm.ClassReader;
-import org.objectweb.asm.ClassVisitor;
-import org.objectweb.asm.ClassWriter;
-import org.objectweb.asm.commons.Remapper;
-import org.objectweb.asm.commons.RemappingClassAdapter;
-
 import java.io.BufferedOutputStream;
 import java.io.File;
 import java.io.FileOutputStream;
@@ -43,6 +26,7 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.io.OutputStreamWriter;
+import java.io.Writer;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Enumeration;
@@ -58,6 +42,25 @@ import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import java.util.zip.ZipException;
 
+import org.apache.maven.plugin.MojoExecutionException;
+import org.apache.maven.plugins.shade.filter.Filter;
+import org.apache.maven.plugins.shade.relocation.Relocator;
+import org.apache.maven.plugins.shade.resource.ManifestResourceTransformer;
+import org.apache.maven.plugins.shade.resource.ResourceTransformer;
+import org.codehaus.plexus.component.annotations.Component;
+import org.codehaus.plexus.logging.AbstractLogEnabled;
+import org.codehaus.plexus.util.IOUtil;
+import org.objectweb.asm.ClassReader;
+import org.objectweb.asm.ClassVisitor;
+import org.objectweb.asm.ClassWriter;
+import org.objectweb.asm.commons.ClassRemapper;
+import org.objectweb.asm.commons.Remapper;
+
+
+import com.google.common.base.Joiner;
+import com.google.common.collect.HashMultimap;
+import com.google.common.collect.Multimap;
+
 /**
  * @author Jason van Zyl
  */
@@ -89,19 +92,18 @@ public class DefaultShader
 
         // noinspection ResultOfMethodCallIgnored
         shadeRequest.getUberJar().getParentFile().mkdirs();
-        FileOutputStream fileOutputStream = new FileOutputStream( shadeRequest.getUberJar() );
-        JarOutputStream jos = new JarOutputStream( new BufferedOutputStream( fileOutputStream ) );
 
+        JarOutputStream out = null;
         try
         {
-
-            goThroughAllJarEntriesForManifestTransformer( shadeRequest, resources, manifestTransformer, jos );
+            out = new JarOutputStream( new BufferedOutputStream( new FileOutputStream( shadeRequest.getUberJar() ) ) );
+            goThroughAllJarEntriesForManifestTransformer( shadeRequest, resources, manifestTransformer, out );
 
             // CHECKSTYLE_OFF: MagicNumber
             Multimap<String, File> duplicates = HashMultimap.create( 10000, 3 );
             // CHECKSTYLE_ON: MagicNumber
 
-            shadeJars( shadeRequest, resources, transformers, remapper, jos, duplicates );
+            shadeJars( shadeRequest, resources, transformers, remapper, out, duplicates );
 
             // CHECKSTYLE_OFF: MagicNumber
             Multimap<Collection<File>, String> overlapping = HashMultimap.create( 20, 15 );
@@ -128,14 +130,16 @@ public class DefaultShader
             {
                 if ( transformer.hasTransformedResource() )
                 {
-                    transformer.modifyOutputStream( jos );
+                    transformer.modifyOutputStream( out );
                 }
             }
 
+            out.close();
+            out = null;
         }
         finally
         {
-            IOUtil.close( jos );
+            IOUtil.close( out );
         }
 
         for ( Filter filter : shadeRequest.getFilters() )
@@ -173,6 +177,13 @@ public class DefaultShader
                         // later
                         continue;
                     }
+                    
+                    if ( "module-info.class".equals( name ) )
+                    {
+                        getLogger().warn( "Discovered module-info.class. "
+                            + "Shading will break its strong encapsulation." );
+                        continue;
+                    }
 
                     if ( !entry.isDirectory() && !isFiltered( jarFilters, name ) )
                     {
@@ -195,11 +206,10 @@ public class DefaultShader
                                  JarEntry entry, String name )
         throws IOException, MojoExecutionException
     {
-        InputStream is = jarFile.getInputStream( entry );
-
+        InputStream in = null;
         try
         {
-
+            in = jarFile.getInputStream( entry );
             String mappedName = remapper.map( name );
 
             int idx = mappedName.lastIndexOf( '/' );
@@ -216,7 +226,7 @@ public class DefaultShader
             if ( name.endsWith( ".class" ) )
             {
                 duplicates.put( name, jar );
-                addRemappedClass( remapper, jos, jar, name, is );
+                addRemappedClass( remapper, jos, jar, name, in );
             }
             else if ( shadeRequest.isShadeSourcesContent() && name.endsWith( ".java" ) )
             {
@@ -226,11 +236,11 @@ public class DefaultShader
                     return;
                 }
 
-                addJavaSource( resources, jos, mappedName, is, shadeRequest.getRelocators() );
+                addJavaSource( resources, jos, mappedName, in, shadeRequest.getRelocators() );
             }
             else
             {
-                if ( !resourceTransformed( transformers, mappedName, is, shadeRequest.getRelocators() ) )
+                if ( !resourceTransformed( transformers, mappedName, in, shadeRequest.getRelocators() ) )
                 {
                     // Avoid duplicates that aren't accounted for by the resource transformers
                     if ( resources.contains( mappedName ) )
@@ -238,14 +248,16 @@ public class DefaultShader
                         return;
                     }
 
-                    addResource( resources, jos, mappedName, is );
+                    addResource( resources, jos, mappedName, entry.getTime(), in );
                 }
             }
 
+            in.close();
+            in = null;
         }
         finally
         {
-            IOUtil.close( is );
+            IOUtil.close( in );
         }
     }
 
@@ -422,7 +434,7 @@ public class DefaultShader
         ClassWriter cw = new ClassWriter( 0 );
 
         final String pkg = name.substring( 0, name.lastIndexOf( '/' ) + 1 );
-        ClassVisitor cv = new RemappingClassAdapter( cw, remapper )
+        ClassVisitor cv = new ClassRemapper( cw, remapper )
         {
             @Override
             public void visitSource( final String source, final String debug )
@@ -516,17 +528,22 @@ public class DefaultShader
             sourceContent = relocator.applyToSourceContent( sourceContent );
         }
 
-        OutputStreamWriter writer = new OutputStreamWriter( jos, "UTF-8" );
+        final Writer writer = new OutputStreamWriter( jos, "UTF-8" );
         IOUtil.copy( sourceContent, writer );
         writer.flush();
 
         resources.add( name );
     }
 
-    private void addResource( Set<String> resources, JarOutputStream jos, String name, InputStream is )
+    private void addResource( Set<String> resources, JarOutputStream jos, String name, long lastModified,
+                              InputStream is )
         throws IOException
     {
-        jos.putNextEntry( new JarEntry( name ) );
+        final JarEntry jarEntry = new JarEntry( name );
+
+        jarEntry.setTime( lastModified );
+
+        jos.putNextEntry( jarEntry );
 
         IOUtil.copy( is, jos );
 
